'use strict'

const vm = require('vm')
const matchHelper = require('posthtml-match-helper')
const { render } = require('posthtml-render')
const { match } = require('posthtml/lib/api')

// const code = 'module.exports = {a: 1}';
const ctx = vm.createContext({ module })

// const r = vm.runInContext(code, ctx)

/**
 * @description Get the script tag with locals attribute from a node list and return locals.
 *
 * @method scriptDataLocals
 *
 * @param  {Array}   tree Nodes
 *
 * @return {Object}   {} Locals
 */
function scriptDataLocals (tree, options) {
  const locals = {}
  const localsAttr = options.localsAttr || 'locals'

  match.call(tree, matchHelper(`script[${localsAttr}]`), node => {
    if (node.content) {
      const code = render(node.content)

      try {
        const local = vm.runInContext(code, ctx)

        Object.assign(locals, local)
      } catch {};
    }

    return node
  })

  return {
    locals
  }
}

module.exports = scriptDataLocals
